@@ -21,7 +21,8 @@ from typing import Iterable
 
 import click
 import requests
-from LbAPCommon import get_api_token, parse_yaml, render_yaml, validate_yaml
+from apd.authentication import get_auth_headers
+from LbAPCommon import parse_yaml, render_yaml, validate_yaml
 from LbAPCommon.checks import run_job_checks
 from LbAPCommon.checks_utils import checks_to_JSON, hist_to_root
 from pkg_resources import DistributionNotFound, get_distribution
@@ -30,7 +31,6 @@ from .checks import checks_exist, perform_checks
 from .log_parsing import show_log_advice
 from .testing import enter_debugging, prepare_reproduce, prepare_test
 from .utils import (
-    LBAPI_CLIENT_ID,
     LBAPI_HOST,
     available_productions,
     check_production,
@@ -71,28 +71,10 @@ def main():
     pass
 
 
-def wipe_token_cache(ctx, param, value):
-    if not value or ctx.resilient_parsing:
-        return
-    from LbAPCommon import wipe_token_cache
-
-    wipe_token_cache(LBAPI_CLIENT_ID)
-    click.secho("Token cache wiped successfully", fg="green")
-    ctx.exit()
-
-
 @main.command()
-@click.option(
-    "--wipe-cache",
-    is_flag=True,
-    callback=wipe_token_cache,
-    expose_value=False,
-    is_eager=True,
-)
 def login():
     """Login to the Analysis Productions API"""
-    token = get_api_token(LBAPI_CLIENT_ID, f"{LBAPI_HOST}/user")
-    r = requests.get(f"{LBAPI_HOST}/user", headers={"Authorization": f"Bearer {token}"})
+    r = requests.get(f"{LBAPI_HOST}/user", **get_auth_headers())
     r.raise_for_status()
     click.secho(f"Logged in successfully as {r.json()['username']}", fg="green")
 
@@ -145,26 +127,22 @@ def versions(working_group: str, production_name: production_name_type) -> None:
 
 
 @main.command()
-@click.argument("version", type=str, nargs=1)
 @click.argument("working_group", type=str, nargs=1)
 @click.argument("production_name", type=production_name_type, nargs=1)
+@click.argument("version", type=str, nargs=1)
 @click.argument("branch_name", type=str, nargs=1)
-@click.argument(
-    "clone_type", type=click.Choice(["ssh", "https", "krb5"]), default="ssh", nargs=1
+@click.option(
+    "--clone-type", type=click.Choice(["ssh", "https", "krb5"]), default="ssh"
 )
 def clone(
-    version: str,
     working_group: str,
     production_name: production_name_type,
+    version: str,
     branch_name: str,
-    clone_type: str,
+    clone_type: str = "ssh",
 ) -> None:
     """Clone the AnalysisProductions repository and do lb-ap checkout
-    with the specified version, production and branch name.
-
-    Specify clone_type as either ssh, https or krb5."""
-    if clone_type not in ["ssh", "https", "krb5"]:
-        raise click.ClickException(f"{clone_type} is not a valid cloning option!")
+    with the specified version, production and branch name."""
     if version not in production_to_versions(working_group, production_name):
         raise click.ClickException(
             f"Version {version} does not correspond to the {production_name} production!."
@@ -186,7 +164,7 @@ def clone(
     if os.path.isdir("./AnalysisProductions"):
         os.chdir("./AnalysisProductions")
         _checkout(
-            version, working_group, production_name, branch_name, allow_deletes=True
+            working_group, production_name, version, branch_name, allow_deletes=True
         )
     else:
         raise click.ClickException(
@@ -196,33 +174,33 @@ def clone(
 
 
 @main.command()
-@click.argument("version", type=str, nargs=1)
 @click.argument("working_group", type=str, nargs=1)
 @click.argument("production_name", type=production_name_type, nargs=1)
+@click.argument("version", type=str, nargs=1)
 @click.argument("branch_name", type=str, nargs=1)
 @click.option("--allow-deletes/--no-allow-deletes", default=False)
 def checkout(
-    version: str,
     working_group: str,
     production_name: production_name_type,
+    version: str,
     branch_name: str,
     allow_deletes: bool,
 ) -> None:
     """Clean out the current copy of the specified production and clone the production from the specified version \n
     List the available tags for a specific production by running 'lb-ap versions <YOUR_PRODUCTION>'"""
     _checkout(
-        version,
         working_group,
         production_name,
+        version,
         branch_name,
         allow_deletes=allow_deletes,
     )
 
 
 def _checkout(
-    version: str,
     working_group: str,
     production_name: production_name_type,
+    version: str,
     branch_name: str,
     *,
     allow_deletes: bool,
@@ -239,7 +217,7 @@ def _checkout(
         raise click.ClickException(
             f"Current git repository is not clean: {proc.stdout}"
         )
-    _run_git("fetch", "origin")
+    _run_git("fetch", "origin", "--tags")
     _run_git("checkout", "-b", branch_name, "origin/master")
 
     for child in repo_dir.iterdir():
