@@ -14,7 +14,7 @@ from os.path import isfile, join
 import pytest
 from click.testing import CliRunner
 
-import LbAPLocal.testing
+import LbAPLocal
 from LbAPLocal.cli import main
 
 
@@ -33,7 +33,16 @@ def test_run_test(
     with_proxy, data_pkg_repo, with_data, name, n_events, monkeypatch, record_mode
 ):
     if record_mode == "none":
-        monkeypatch.setattr(LbAPLocal.testing, "get_api_token", lambda x, y: "")
+        monkeypatch.setattr(
+            LbAPLocal.cli,
+            "get_auth_headers",
+            lambda: dict(headers={"Authorization": "Bearer "}),
+        )
+        monkeypatch.setattr(
+            LbAPLocal.testing,
+            "get_auth_headers",
+            lambda: dict(headers={"Authorization": "Bearer "}),
+        )
 
     runner = CliRunner()
     result = runner.invoke(main, ["test", "executabletests", name, "--no-validate"])
